@@ -1,6 +1,6 @@
 use strict; use warnings;
 package Inline::Module;
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 our $API_VERSION = 'v2';
 
 use Carp 'croak';
@@ -12,7 +12,7 @@ use File::Spec();
 my $inline_build_path = '.inline';
 
 use constant DEBUG_ON => $ENV{PERL_INLINE_MODULE_DEBUG} ? 1 : 0;
-sub DEBUG { if (DEBUG_ON) { print "DEBUG >>> ", sprintf(@_), "\n" }}
+sub DEBUG { if (DEBUG_ON) { print "DEBUG >>> ", sprintf(shift, @_), "\n" }}
 
 #------------------------------------------------------------------------------
 # This import serves multiple roles:
@@ -22,7 +22,7 @@ sub DEBUG { if (DEBUG_ON) { print "DEBUG >>> ", sprintf(@_), "\n" }}
 #------------------------------------------------------------------------------
 sub import {
     my $class = shift;
-    DEBUG_ON && DEBUG "Inline::Module::import(@_)";
+    DEBUG_ON && DEBUG "$class->import(@_)";
 
     my ($stub_module, $program) = caller;
     $program =~ s!.*[\\\/]!!;
@@ -119,6 +119,7 @@ sub importer {
 #------------------------------------------------------------------------------
 sub postamble {
     my ($makemaker, %args) = @_;
+    DEBUG_ON && DEBUG "Inline::Module::postamble(${\join', ',@_})";
 
     my $meta = $args{inline}
         or croak "'postamble' section requires 'inline' key in Makefile.PL";
@@ -162,6 +163,7 @@ pure_all ::
 #------------------------------------------------------------------------------
 sub handle_stub {
     my ($class, $stub_module, $api_version) = @_;
+    DEBUG_ON && DEBUG "$class->handle_stub($stub_module, $api_version)";
     $class->check_api_version($stub_module, $api_version);
     no strict 'refs';
     *{"${stub_module}::import"} = $class->importer($stub_module);
@@ -170,6 +172,7 @@ sub handle_stub {
 
 sub handle_makestub {
     my ($class, @args) = @_;
+    DEBUG_ON && DEBUG "$class->handle_makestub(${\join', ',@args})";
 
     my @modules;
     for my $arg (@args) {
@@ -188,6 +191,7 @@ sub handle_makestub {
 
 sub handle_distdir {
     my ($class, $distdir, @args) = @_;
+    DEBUG_ON && DEBUG "$class->handle_distdir($distdir, ${\join', ',@args})";
     my $stub_modules = [];
     my $included_modules = [];
 
@@ -202,6 +206,7 @@ sub handle_distdir {
 
 sub handle_fixblib {
     my ($class) = @_;
+    DEBUG_ON && DEBUG "$class->handle_fixblib()";
     my $ext = $Config::Config{dlext};
     -d 'blib'
         or die "Inline::Module::fixblib expected to find 'blib' directory";
@@ -238,6 +243,7 @@ sub default_meta {
 
 sub included_modules {
     my ($class, $meta) = @_;
+    DEBUG_ON && DEBUG "$class->included_modules($meta)";
     return [] if not $meta->{bundle};
     my $ilsm = $meta->{ilsm};
     my $include = [
@@ -268,6 +274,7 @@ sub included_modules {
 
 sub add_to_distdir {
     my ($class, $distdir, $stub_modules, $included_modules) = @_;
+    DEBUG_ON && DEBUG "$class->add_to_distdir($distdir) [@$stub_modules] [@$included_modules]";
     my $manifest = []; # files created under distdir
     for my $module (@$stub_modules) {
         my $code = $class->dyna_module($module);
@@ -295,6 +302,7 @@ sub add_to_distdir {
 
 sub make_stub_modules {
     my ($class, @modules) = @_;
+    DEBUG_ON && DEBUG "$class->make_stub_modules(@modules)";
 
     for my $module (@modules) {
         my $code = $class->proxy_module($module);
@@ -323,6 +331,7 @@ sub read_share_cpp_config {
 
 sub proxy_module {
     my ($class, $module) = @_;
+    DEBUG_ON && DEBUG "$class->proxy_module($module)";
 
     return <<"...";
 # DO NOT EDIT. GENERATED BY: Inline::Module
@@ -344,6 +353,7 @@ use Inline::Module stub => '$API_VERSION';
 
 sub dyna_module {
     my ($class, $module) = @_;
+    DEBUG_ON && DEBUG "$class->dyna_module($module)";
     return <<"...";
 # DO NOT EDIT. GENERATED BY: Inline::Module $Inline::Module::VERSION
 
@@ -361,6 +371,7 @@ bootstrap $module;
 
 sub read_file {
     my ($class, $filepath) = @_;
+    DEBUG_ON && DEBUG "$class->read_file($filepath)";
     open IN, '<', $filepath
         or die "Can't open '$filepath' for input:\n$!";
     my $code = do {local $/; <IN>};
@@ -369,7 +380,9 @@ sub read_file {
 }
 
 sub write_module {
-    my ($class, $dest, $module, $code, $onchange) = @_;
+    my $class = shift;
+    my ($dest, $module, $code, $onchange) = @_;
+    DEBUG_ON && DEBUG "$class->write_module($dest, $module, ..., $onchange)";
     $onchange ||= 0;
 
     $code =~ s/\n+__END__\n.*//s;
@@ -396,6 +409,7 @@ sub write_module {
 
 sub add_to_manifest {
     my ($class, $distdir, @files) = @_;
+    DEBUG_ON && DEBUG "$class->add_to_manifest($distdir) (@files)";
     my $manifest = "$distdir/MANIFEST";
 
     if (-w $manifest) {
